@@ -1,7 +1,19 @@
 #' @title  Edit Snippet
-#' @description Snippet for the package BayesianFROC. Copy and paste to the snippet edition tools in your R studio for the conforable usage of the package BayesianFROC. This is under construction. To edit snippet, you should open the editor located in Tools > Global options > Code > Edit snippets.
+#' @description Snippet for the package BayesianFROC. Copy and paste to the snippet edition tools in your R studio for the conforable usage of the package BayesianFROC. This is under construction. To edit snippet, you can open, by R-stuido, the editor located in Tools > Global options > Code > Edit snippets.
 #' @return nothing
 #' @export
+#' @details
+#'
+#'  if $ are included such as
+#'
+#'          foo$b
+#'
+#'           then in message it should be
+#'
+#'      message("foo\\$a")
+#'
+#'2020 JUly2
+#'
 #'
 #' @examples
 #'
@@ -10,6 +22,10 @@
 snippet_for_BayesianFROC  <- function(){
 
 message("
+
+snippet iii
+	install.packages(${1:\"BayesianFROC\"})
+
 snippet www
 	devtools::load_all(\".\");
 
@@ -51,60 +67,84 @@ snippet citation
 
 snippet download
   BayesianFROC::dark_theme()
-	a<-	cranlogs::cran_downloads(
-	packages = \"BayesianFROC\",
-	from = \"2019-05-12\",#from = \"2019-05-03\",
-	to = Sys.Date())
-	a
-	b <- a\\$count;
-	number.of.downloads <-b;
-	mean(b)
-	date<- 1:as.integer(length(b))
-	plot(date,number.of.downloads  ,type=\"l\")
-  graphics::abline(h=0)
-  graphics::abline(h=10)
-  graphics::abline(h=20)
-  graphics::abline(h=30)
-  graphics::abline(h=40)
-  graphics::abline(h=50)
+  a<-    cranlogs::cran_downloads(
+  packages = \"BayesianFROC\",
+  from = \"2019-05-12\",
+  #from = \"2019-05-03\",
+  to = Sys.Date())
+  a
+  b <- a\\$count;
+  number.of.downloads <-b;
+  mean(b)
+  date<- 1:as.integer(length(b))
+
+  today <- b[length(b)-2]
+  title <- paste(\"today = \",today ,\",\",
+  b[length(b)-3],\",\",
+  b[length(b)-4],\",\",
+  b[length(b)-5],\",\",
+  b[length(b)-6],\",\",
+  b[length(b)-7],\",\",
+  b[length(b)-8],\",\",
+  b[length(b)-9]
+  )
+
+  plot(date,number.of.downloads  ,type=\"l\",col=\"yellow\", main  = title)
+  for (hhh in (0:5)*10) graphics::abline(h=hhh)
+  graphics::abline(h=b[length(b)-4], col=\"red\",lty =\"dashed\",lwd =\"2\")
+  graphics::abline(h=b[length(b)-3], col=\"red\",lty =\"dashed\",lwd =\"3\")
+  graphics::abline(h=b[length(b)-2], col=\"red\",lty =\"solid\",lwd =\"3\")
+
+  plot(date, cumsum(b), type=\"l\",col=\"yellow\", main  = title)
+
+  hist(b,col = \"red\",border=\"yellow\",breaks=77, main  = title)
+
+  for (aaa in 1:50) {
+  graphics::abline(h=aaa)
+  if (aaa%%5==0) {
+    graphics::abline(h=aaa,lwd =\"2\")
+    # graphics::abline(v=5,lwd =\"2\")
+    # # graphics::abline(v=15,lwd =\"1\",lty =\"dashed\")
+  }
+  }
+
+
+
+  graphics::abline(v =b[length(b)-2], untf = FALSE, col=\"red\",lty =\"solid\",lwd =\"4\");
+  graphics::abline(v =b[length(b)-2]-1, untf = FALSE, col=\"red\",lty =\"solid\",lwd =\"4\")
+
+  graphics::abline(v =b[length(b)-3], untf = FALSE, col=\"red\",lty =\"dashed\",lwd =\"2\");
+  graphics::abline(v =b[length(b)-3]-1, untf = FALSE, col=\"red\",lty =\"dashed\",lwd =\"2\")
+
+  graphics::abline(v =b[length(b)-4], untf = FALSE, col=\"red\",lty =\"dotdash\",lwd =\"1\");
+  graphics::abline(v =b[length(b)-4]-1, untf = FALSE, col=\"red\",lty =\"dotdash\",lwd =\"1\")
+
+
+  # df<-data.frame(b=b)
+  # g <- ggplot2::ggplot(df, ggplot2::aes(x = b))
+  # g <- g + ggplot2::geom_histogram(binwidth = 1)
+  # plot(g)
+  #x<-runif(1000)/10;for(i in 1:1000) y[i]<-  mean(b,trim = x[i]);plot(x,y)
+
+
+  sum(b)
+
+
+  jjj<-length(b)
+  tails <-list( length =  jjj  , mode = \"vector\")
+  tail_area <- vector(length =  jjj, mode = \"numeric\")
+  for (iii in 1:jjj) {
+  tails[[iii]] <- b[b>b[length(b)-iii]]
+  tail_area[iii] <- length(tails[[iii]]) /length(b)
+  }
+ tail_area_rev <- rev(tail_area)
+ tail_area_rev <- round(tail_area_rev,digits = 3)
+ tail_area_rev
+  # hist(tail_area)
+ plot(date,tail_area_rev  ,type=\"l\",col=\"yellow\", main  = title)
+ graphics::abline(h=0.5,lwd =\"2\")
 
-	hist(b,col = \"red\",border=\"white\",breaks=77)
-	graphics::abline(h=1)
-	graphics::abline(h=2)
-	graphics::abline(h=3)
-	graphics::abline(h=4)
-	graphics::abline(h=5)
-	graphics::abline(h=6)
-	graphics::abline(h=7)
-	graphics::abline(h=8)
-	graphics::abline(h=9)
-	graphics::abline(h=10)
-	graphics::abline(h=11)
-	graphics::abline(h=12)
-	graphics::abline(h=13)
-	graphics::abline(h=14)
-	graphics::abline(h=15)
-	graphics::abline(h=16)
-	graphics::abline(h=17)
-	graphics::abline(h=18)
-	graphics::abline(h=19)
-	graphics::abline(h=20)
-	graphics::abline(h=21)
-	graphics::abline(h=22)
-	graphics::abline(h=23)
-	graphics::abline(h=24)
-	graphics::abline(h=25)
-	graphics::abline(h=26)
-	graphics::abline(h=27)
-	graphics::abline(h=28)
-	graphics::abline(h=29)
-  graphics::abline(v =b[length(b)-2], untf = FALSE);
-  graphics::abline(v =b[length(b)-2]-1, untf = FALSE)
 
-	df<-data.frame(b=b)
-  g <- ggplot2::ggplot(df, ggplot2::aes(x = b))
-  g <- g + ggplot2::geom_histogram(binwidth = 1)
-  plot(g)
 
 snippet fff.pkg.detach
 	detach(\"package:BayesianFROC\")
